@@ -4,7 +4,7 @@ use 5.020;
 use Archive::Libarchive qw( :const );
 
 my $r = Archive::Libarchive::ArchiveRead->new;
-$r->support_compression_all;
+$r->support_filter_all;
 $r->support_format_all;
 
 my $fh;
